pub struct VolumeConstraint {
pub indices: [usize; 4],
pub rest_volume: Real,
pub compliance: Real,
/* private fields */
}Expand description
Volume-preservation constraint for a tetrahedral mesh.
Operates over all tetrahedra whose indices are stored in the constraint.
Fields
indices: [usize; 4]Indices of the four vertices forming the tetrahedron.
rest_volume: RealRest volume (positive).
compliance: RealCompliance (XPBD).
Implementations
Sourceimpl VolumeConstraint
impl VolumeConstraint
Sourcepub fn new(indices: [usize; 4], rest_volume: Real, compliance: Real) -> Self
pub fn new(indices: [usize; 4], rest_volume: Real, compliance: Real) -> Self
Create a volume constraint with an explicit rest volume.
Sourcepub fn from_particles(
indices: [usize; 4],
particles: &[SoftParticle],
compliance: Real,
) -> Self
pub fn from_particles( indices: [usize; 4], particles: &[SoftParticle], compliance: Real, ) -> Self
Build a volume constraint whose rest volume matches the current configuration.
Sourcepub fn reset_lambda(&mut self)
pub fn reset_lambda(&mut self)
Reset the Lagrange multiplier.